package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: May 17, 2023
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Selection(jsonData, headerText, footerText string, perPage int) string
type ListItem struct {
Text string `json:"text"`
Description string `json:"description"`
}
type Result struct {
SelectedIndex string `json:"selectedIndex"`
Error string `json:"error"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.